.. :changelog:

History
-------

0.2.0 (2016-11-17)
++++++++++++++++++

* Add django admin interface.
* Add migrations folder.
* Add log policies for submitting tasks.
* Add return value for modified files.

0.1.1 (2016-11-15)
++++++++++++++++++

* Add port number to Server model.
* Add task to submit jobs.
* Add status updates to task.
* Fix unicode error when submitting jobs.
* Fix verbose/related names for models.

0.1.0 (2016-11-08)
++++++++++++++++++

* First release on PyPI.
